//////////////////////////////////////////////////////////////////
//  TKLTrack
//
//    Track data object
//
// $Id:$
// Author: Dan Dwyer
//////////////////////////////////////////////////////////////////

#include "TKLTrack.hh"

ClassImp(TKLTrack)
////////////////////////////////////////////////////////////////
//
// TKLTrack: A class for storing and manipulating track data 
//

void TKLTrack::Streamer(TBuffer &R__b)
{
   // Stream an object of class TKLTrack.
   if (R__b.IsReading()) {
     UInt_t R__s, R__c;
     Version_t R__v = R__b.ReadVersion(&R__s,&R__c);
     if(R__v >=3 ){
       TKLTrack::Class()->ReadBuffer(R__b, this, R__v, R__s, R__c);
     }else{
       // Read Subclass info
       TKLDataObject::Streamer(R__b);
       // For older tracks, must convert to new midpoint/velocity format
       Float_t entrance[4],exit[4];
       for(Int_t i=0;i<4;i++) R__b >> entrance[i];
       for(Int_t i=0;i<4;i++) R__b >> exit[i];
       for(Int_t i=0;i<3;i++) fMidpoint[i]=(entrance[i]+exit[i])/2.0;
       for(Int_t i=0;i<3;i++) fVelocity[i]=exit[i]-entrance[i];
       fVelocity.SetMag(1.0);
       fTime=(exit[3]-entrance[3])/2.0;
       R__b >> fEnergy;
       if(R__v == 1){
	 // Version 1 had covariance matrix
	 Float_t covar[7][7];
	 for(Int_t i=0;i<7;i++){
	   for(Int_t j=0;j<7;j++) R__b >> covar[i][j];
	 }
       }
       if(R__v == 2){
	 // Version >= 2 has ChiSquare and NDF
	 R__b >> fChiSquare;
	 R__b >> fNDF;
       }
       R__b >> fStatus;
       // Version <= 2 had a recon status
       Float_t reconStatus;
       R__b >> reconStatus;

       // Moved FixMuonTrack functionality to Streamer! :)
       if(fStatus==1 && reconStatus==-2) fStatus=2;
       if(fChiSquare>4.0 || (fChiSquare>0.7 && fEnergy<2.5e6))
	 fStatus=3;

       // Version <=2 had an Event Index
       Int_t eventIndex;
       R__b >> eventIndex;
       // Done with streaming old versions
       R__b.CheckByteCount(R__s,R__c,TKLTrack::IsA());
     }
   } else {
      TKLTrack::Class()->WriteBuffer(R__b, this);
   }
}
